@@ -3,7 +3,7 @@
 # If you want to add MIME types,
 # you must add an entry in MimeFamily and may be MimeHashLib
 #-------------------------------------------------------
-# $Revision: 1.20 $ - $Author: eldy $ - $Date: 2005/01/21 22:49:05 $
+# $Revision: 1.22 $ - $Author: eldy $ - $Date: 2005/12/17 16:05:10 $
 
 
 #package AWSMIME;
@@ -14,25 +14,34 @@
 #---------------------------------------------------------------
 %MimeHashLib = (
 'text',      'Text file',
-'page',      'HTML&nbsp;or&nbsp;XML&nbsp;static&nbsp;page',
-'script',    'Dynamic&nbsp;Html&nbsp;page&nbsp;or&nbsp;Script&nbsp;file',
+'page',      'HTML or XML static page',
+'script',    'Dynamic Html page or Script file',
+'pl',        'Dynamic Perl Script file',
+'php',       'Dynamic PHP Script file',
 'image',     'Image',
 'document',  'Document',
 'package',   'Package',
 'archive',   'Archive',
-'audio',     'Audio',
-'video',     'Video',
-'javascript','Javascript file',
+'audio',     'Audio file',
+'video',     'Video file',
+'javascript','JavaScript file',
 'vbs',       'Visual Basic script',
 'conf',      'Config file',
 'css',       'Cascading Style Sheet file',
-'xsl',       'Extensible&nbsp;Stylesheet&nbsp;Language&nbsp;file',
-'runtime',   'HTML&nbsp;dynamic&nbsp;page&nbsp;or&nbsp;Binary&nbsp;runtime',
+'xsl',       'Extensible Stylesheet Language file',
+'runtime',   'Binary runtime',
 'library',   'Binary library',
 'swf',       'Macromedia Flash Animation',
 'dtd',       'Document Type Definition',
 'csv',       'Comma Separated Value file',
 'jnlp',      'Java Web Start launch file',
+'lit',       'Microsoft Reader e-book',
+'svg',       'Scalable Vector Graphics',
+'ai',        'Adobe Illustrator file',
+'phshop',    'Adobe Photoshop image file',
+'ttf',       'TrueType scalable font file',
+'fon',       'Font file',
+'pdf',       'Adobe Acrobat file',
 );
 
 # MimeHashIcon
@@ -42,13 +51,17 @@
 %MimeHashIcon = (
 # Text file
 'txt','text',
+'log','text',
 # HTML Static page
 'html','html',
 'htm','html',
 'hdml','html',
 'wml','html',
 'wmlp','html',
+'xhtml','html',
 'xml','html',
+'sgm','html',
+'sgml','html',
 # HTML Dynamic pages or script
 'asp','script',
 'aspx','script', 
@@ -57,10 +70,10 @@
 'jsp','script',
 'cgi','script',
 'ksh','script',
-'php','script',
-'php3','script',
-'php4','script',
-'pl','script',
+'php','php',
+'php3','php',
+'php4','php',
+'pl','pl',
 'py','script',
 'sh','script',
 'shtml','html',
@@ -72,18 +85,26 @@
 'bmp','image',
 'jpg','image',
 'jpeg','image',
+'cdr','image',
+'ico','image',
+'svg','svg',
+'psd','phshop',
 # Document
 'doc','doc',
+'wmz','doc',
+'rtf','doc',
 'pdf','pdf',
-'xls','other',
-'ppt','other',
-'pps','other',
+'xls','xls',
+'ppt','ppt',
+'pps','ppt',
 'sxw','other',
 'sxc','other',
 'sxi','other',
 'sxd','other',
 'csv','other',
 'xsl','html',
+'lit','lit',
+'ai','ai',
 # Package
 'rpm',($LogType eq 'S'?'audio':'archive'),
 'deb','archive',
@@ -111,11 +132,14 @@
 'mp4','video',
 'mpeg','video',
 'mpg','video',
-'rm','video',
-'swf','video',
+'rm','real',
+'swf','flash',
+'wmv','video',
+'mov','quicktime',
+'qt','quicktime',
 # Web scripts
-'js','other',
-'vbs','other',
+'js','jscript',
+'vbs','jscript',
 # Config
 'cf','other',
 'conf','other',
@@ -126,18 +150,25 @@
 'exe','script',
 'dll','script',
 'jnlp','jnlp',
+# Fonts
+'ttf','ttf',
+'fon','fon',
 );
 
 
 %MimeHashFamily=(
 # Text file
-'txt','page',
+'txt','text',
+'log','text',
 # HTML Static page
 'html','page',
 'htm','page',
 'wml','page',
 'wmlp','page',
+'xhtml','page',
 'xml','page',
+'sgm','page',
+'sgml','page',
 # HTML Dynamic pages or script
 'asp','script',
 'aspx','script', 
@@ -146,10 +177,10 @@
 'jsp','script',
 'cgi','script',
 'ksh','script',
-'php','script',
-'php3','script',
-'php4','script',
-'pl','script',
+'php','php',
+'php3','php',
+'php4','php',
+'pl','pl',
 'py','script',
 'sh','script',
 'shtml','script',
@@ -161,9 +192,16 @@
 'bmp','image',
 'jpg','image',
 'jpeg','image',
+'cdr','image',
+'ico','image',
+'svg','svg',
+'psd','phshop',
+'ai','ai',
 # Document
 'doc','document',
-'pdf','document',
+'wmz','document',
+'rtf','document',
+'pdf','pdf',
 'xls','document',
 'ppt','document',
 'pps','document',
@@ -173,6 +211,7 @@
 'sxd','document',
 'csv','csv',
 'xsl','xsl',
+'lit','lit',
 # Package
 'rpm',($LogType eq 'S'?'audio':'package'),
 'deb','package',
@@ -202,6 +241,9 @@
 'mpg','video',
 'rm','video',
 'swf','swf',
+'wmv','video',
+'mov','video',
+'qt','video',
 # Web scripts
 'js','javascript',
 'vbs','vbs',
@@ -215,6 +257,9 @@
 'exe','runtime',
 'jnlp','jnlp',
 'dll','library',
+# Font
+'ttf','ttf',
+'fon','fon',
 );
 
 
