@@ -8,7 +8,7 @@
 #-----------------------------------------------------------------------------
 # Perl Required Modules: Geo::IP or Geo::IP::PurePerl
 #-----------------------------------------------------------------------------
-# $Revision: 1.15 $ - $Author: eldy $ - $Date: 2005/02/19 13:40:42 $
+# $Revision: 1.21 $ - $Author: eldy $ - $Date: 2005/08/23 20:14:06 $
 
 
 # <-----
@@ -53,7 +53,8 @@ sub Init_geoip {
 	# <-----
 	# ENTER HERE CODE TO DO INIT PLUGIN ACTIONS
 	debug(" Plugin geoip: InitParams=$InitParams",1);
-	my $mode=$InitParams;
+   	my ($mode,$datafile)=split(/\s+/,$InitParams,2);
+   	if (! $datafile) { $datafile="GeoIP.dat"; }
 	if ($type eq 'geoippureperl') {
 		if ($mode eq '' || $mode eq 'GEOIP_MEMORY_CACHE')  { $mode=Geo::IP::PurePerl::GEOIP_MEMORY_CACHE(); }
 		else { $mode=Geo::IP::PurePerl::GEOIP_STANDARD(); }
@@ -64,9 +65,9 @@ sub Init_geoip {
 	%TmpDomainLookup=();
 	debug(" Plugin geoip: GeoIP initialized in mode $type $mode",1);
 	if ($type eq 'geoippureperl') {
-		$gi = Geo::IP::PurePerl->new($mode);
+		$gi = Geo::IP::PurePerl->open($datafile, $mode);
 	} else {
-		$gi = Geo::IP->new($mode);
+		$gi = Geo::IP->open($datafile, $mode);
 	}
 	# ----->
 
@@ -85,7 +86,7 @@ sub GetCountryCodeByName_geoip {
 	my $res=$TmpDomainLookup{$param}||'';
 	if (! $res) {
 		$res=lc($gi->country_code_by_name($param));
-		$TmpDomainLookup{$param}=$res;
+		$TmpDomainLookup{$param}=$res || 'unknown';
 		if ($Debug) { debug("  Plugin geoip: GetCountryCodeByName for $param: [$res]",5); }
 	}
 	elsif ($Debug) { debug("  Plugin geoip: GetCountryCodeByName for $param: Already resolved to $res",5); }
@@ -104,7 +105,7 @@ sub GetCountryCodeByAddr_geoip {
 	my $res=$TmpDomainLookup{$param}||'';
 	if (! $res) {
 		$res=lc($gi->country_code_by_addr($param));
-		$TmpDomainLookup{$param}=$res;
+		$TmpDomainLookup{$param}=$res || 'unknown';
 		if ($Debug) { debug("  Plugin geoip: GetCountryCodeByAddr for $param: $res",5); }
 	}
 	elsif ($Debug) { debug("  Plugin geoip: GetCountryCodeByAddr for $param: Already resolved to $res",5); }
@@ -141,7 +142,7 @@ sub ShowInfoHost_geoip {
     	if ($NewLinkParams) { $NewLinkParams="${NewLinkParams}&"; }
 
 		print "<th width=\"80\">";
-        print "<a href=\"#countries\">GeoIP<br>Country</a>";
+        print "<a href=\"#countries\">GeoIP<br />Country</a>";
         print "</th>";
 	}
 	elsif ($param) {
@@ -159,16 +160,16 @@ sub ShowInfoHost_geoip {
 		if ($key && $ip==4) {
         	my $res=lc($gi->country_code_by_addr($param)) if $gi;
         	if ($Debug) { debug("  Plugin geoip: GetCountryByIp for $param: [$res]",5); }
-		    if ($res) { print $DomainsHashIDLib{$res}; }
+		    if ($res) { print $DomainsHashIDLib{$res}?$DomainsHashIDLib{$res}:"<span style=\"color: #$color_other\">$Message[0]</span>"; }
 		    else { print "<span style=\"color: #$color_other\">$Message[0]</span>"; }
 		}
 		if ($key && $ip==6) {
 		    print "<span style=\"color: #$color_other\">$Message[0]</span>";
 		}
 		if (! $key) {
-        	my $res=lc($gi->country_code_by_addr($param)) if $gi;
+        	my $res=lc($gi->country_code_by_name($param)) if $gi;
         	if ($Debug) { debug("  Plugin geoip: GetCountryByHostname for $param: [$res]",5); }
-		    if ($res) { print $DomainsHashIDLib{$res}; }
+		    if ($res) { print $DomainsHashIDLib{$res}?$DomainsHashIDLib{$res}:"<span style=\"color: #$color_other\">$Message[0]</span>"; }
 		    else { print "<span style=\"color: #$color_other\">$Message[0]</span>"; }
 		}
 		print "</td>";
